==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/fi/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "tänä neljänneksenä",
	"field-quarter-short-relative+1": "ensi neljänneksenä",
	"field-tue-relative+-1": "viime tiistaina",
	"field-year": "vuosi",
	"dateFormatItem-Hm": "H.mm",
	"field-wed-relative+0": "tänä keskiviikkona",
	"field-wed-relative+1": "ensi keskiviikkona",
	"dateFormatItem-ms": "mm.ss",
	"timeFormat-short": "H.mm",
	"field-minute": "minuutti",
	"field-month-narrow-relative+-1": "viime kk",
	"field-tue-narrow-relative+0": "tänä ti",
	"field-tue-narrow-relative+1": "ensi ti",
	"field-thu-short-relative+0": "tänä to",
	"field-day-short-relative+-1": "eilen",
	"field-thu-short-relative+1": "ensi to",
	"field-day-relative+0": "tänään",
	"field-day-short-relative+-2": "toissap.",
	"field-day-relative+1": "huomenna",
	"field-week-narrow-relative+0": "tällä vk",
	"field-day-relative+2": "ylihuomenna",
	"field-week-narrow-relative+1": "ensi vk",
	"field-wed-narrow-relative+-1": "viime ke",
	"field-year-narrow": "v",
	"field-year-narrow-relative+0": "tänä v",
	"field-tue-relative+0": "tänä tiistaina",
	"field-year-narrow-relative+1": "ensi v",
	"field-tue-relative+1": "ensi tiistaina",
	"field-second-short": "s",
	"dayPeriods-format-narrow-am": "ap.",
	"dateFormatItem-MMMd": "d. MMM",
	"dayPeriods-format-abbr-am": "ap.",
	"field-week-relative+0": "tällä viikolla",
	"field-month-relative+0": "tässä kuussa",
	"field-week-relative+1": "ensi viikolla",
	"field-month-relative+1": "ensi kuussa",
	"field-sun-narrow-relative+0": "tänä su",
	"timeFormat-medium": "H.mm.ss",
	"field-mon-short-relative+0": "tänä ma",
	"field-sun-narrow-relative+1": "ensi su",
	"field-mon-short-relative+1": "ensi ma",
	"field-second-relative+0": "nyt",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"T",
		"H",
		"K",
		"T",
		"S",
		"A",
		"A",
		"N",
		"I",
		"S",
		"T",
		"A",
		"E"
	],
	"dayPeriods-standAlone-abbr-pm": "ip.",
	"field-month-short": "kk",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-day": "päivä",
	"field-year-relative+-1": "viime vuonna",
	"dayPeriods-format-wide-am": "ap.",
	"field-sat-short-relative+-1": "viime la",
	"field-hour-relative+0": "tämän tunnin aikana",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-second-short-relative+0": "nyt",
	"field-wed-relative+-1": "viime keskiviikkona",
	"dateTimeFormat-medium": "{1} 'klo' {0}",
	"field-sat-narrow-relative+-1": "viime la",
	"field-second": "sekunti",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"dayPeriods-standAlone-wide-pm": "ip.",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "tunnin sisällä",
	"field-quarter": "neljännesvuosi",
	"field-week-short": "vk",
	"field-day-narrow-relative+0": "tänään",
	"field-day-narrow-relative+1": "huom.",
	"field-day-narrow-relative+2": "ylihuom.",
	"quarters-standAlone-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"field-tue-short-relative+0": "tänä ti",
	"field-tue-short-relative+1": "ensi ti",
	"field-month-short-relative+-1": "viime kk",
	"field-mon-relative+-1": "viime maanantaina",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "kuukausi",
	"field-day-narrow": "pv",
	"field-minute-short": "min",
	"field-dayperiod": "vuorokaudenaika",
	"field-sat-short-relative+0": "tänä la",
	"field-sat-short-relative+1": "ensi la",
	"dayPeriods-format-narrow-pm": "ip.",
	"dateFormat-medium": "d.M.y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"quarters-standAlone-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"dayPeriods-format-abbr-pm": "ip.",
	"dateFormatItem-yyyyM": "L.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "tänä maanantaina",
	"field-mon-relative+1": "ensi maanantaina",
	"field-day-narrow-relative+-1": "eilen",
	"field-year-short": "v",
	"field-day-narrow-relative+-2": "toissap.",
	"months-format-narrow": [
		"T",
		"H",
		"K",
		"T",
		"S",
		"A",
		"A",
		"N",
		"I",
		"S",
		"T",
		"A",
		"E"
	],
	"field-quarter-relative+-1": "viime neljännesvuonna",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dayPeriods-standAlone-narrow-am": "ap.",
	"field-week-narrow-relative+-1": "viime vk",
	"days-format-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dayPeriods-format-wide-pm": "ip.",
	"field-sat-relative+-1": "viime lauantaina",
	"dateTimeFormat-long": "{1} 'klo' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-minute-narrow-relative+0": "minuutin sisällä",
	"field-hour": "tunti",
	"months-format-wide": [
		"tišríkuuta",
		"hešvánkuuta",
		"kislévkuuta",
		"tevétkuuta",
		"ševátkuuta",
		"adárkuuta I",
		"adárkuuta",
		"nisánkuuta",
		"ijjárkuuta",
		"sivánkuuta",
		"tammúzkuuta",
		"abkuuta",
		"elúlkuuta"
	],
	"dateFormat-full": "cccc d. MMMM y G",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-Hms": "H.mm.ss",
	"field-quarter-short": "neljännes",
	"field-sat-narrow-relative+0": "tänä la",
	"field-fri-relative+0": "tänä perjantaina",
	"field-sat-narrow-relative+1": "ensi la",
	"field-fri-relative+1": "ensi perjantaina",
	"field-month-narrow-relative+0": "tässä kk",
	"field-month-narrow-relative+1": "ensi kk",
	"field-sun-short-relative+0": "tänä su",
	"field-sun-short-relative+1": "ensi su",
	"field-week-relative+-1": "viime viikolla",
	"field-quarter-short-relative+-1": "viime neljänneksenä",
	"field-minute-short-relative+0": "minuutin sisällä",
	"months-format-abbr": [
		"tišríkuuta",
		"hešvánkuuta",
		"kislévkuuta",
		"tevétkuuta",
		"ševátkuuta",
		"adárkuuta I",
		"adárkuuta",
		"nisánkuuta",
		"ijjárkuuta",
		"sivánkuuta",
		"tammúzkuuta",
		"abkuuta",
		"elúlkuuta"
	],
	"field-quarter-relative+0": "tänä neljännesvuonna",
	"field-minute-relative+0": "tämän minuutin aikana",
	"timeFormat-long": "H.mm.ss z",
	"field-quarter-relative+1": "ensi neljännesvuonna",
	"field-wed-short-relative+-1": "viime ke",
	"dateFormat-short": "d.M.y GGGGG",
	"field-thu-short-relative+-1": "viime to",
	"field-year-narrow-relative+-1": "viime v",
	"days-standAlone-wide": [
		"sunnuntai",
		"maanantai",
		"tiistai",
		"keskiviikko",
		"torstai",
		"perjantai",
		"lauantai"
	],
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "viime ma",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "viime to",
	"field-tue-narrow-relative+-1": "viime ti",
	"dateFormatItem-H": "H",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "ip.",
	"field-wed-short-relative+0": "tänä ke",
	"months-standAlone-wide": [
		"tišríkuu",
		"hešvánkuu",
		"kislévkuu",
		"tevétkuu",
		"ševátkuu",
		"adárkuu I",
		"adárkuu",
		"nisánkuu",
		"ijjárkuu",
		"sivánkuu",
		"tammúzkuu",
		"abkuu",
		"elúlkuu"
	],
	"field-wed-short-relative+1": "ensi ke",
	"field-sun-relative+-1": "viime sunnuntaina",
	"days-standAlone-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"field-second-narrow-relative+0": "nyt",
	"dateTimeFormat-full": "{1} 'klo' {0}",
	"dateFormatItem-hm": "h.mm a",
	"field-weekday": "viikonpäivä",
	"field-day-short-relative+0": "tänään",
	"months-standAlone-narrow-leap": "A",
	"field-quarter-narrow-relative+0": "tänä nelj.",
	"field-sat-relative+0": "tänä lauantaina",
	"field-day-short-relative+1": "huom.",
	"field-quarter-narrow-relative+1": "ensi nelj.",
	"field-sat-relative+1": "ensi lauantaina",
	"field-day-short-relative+2": "ylihuom.",
	"field-week-short-relative+0": "tällä vk",
	"field-week-short-relative+1": "ensi vk",
	"months-standAlone-abbr": [
		"tišrí",
		"hešván",
		"kislév",
		"tevét",
		"ševát",
		"adár I",
		"adár",
		"nisán",
		"ijjár",
		"siván",
		"tammúz",
		"ab",
		"elúl"
	],
	"months-format-wide-leap": "adárkuuta II",
	"field-month-short-relative+0": "tässä kk",
	"field-month-short-relative+1": "ensi kk",
	"timeFormat-full": "H.mm.ss zzzz",
	"dateFormatItem-MEd": "E d.M.",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "tänä to",
	"field-thu-narrow-relative+1": "ensi to",
	"field-sun-narrow-relative+-1": "viime su",
	"field-mon-short-relative+-1": "viime ma",
	"field-thu-relative+0": "tänä torstaina",
	"field-thu-relative+1": "ensi torstaina",
	"field-fri-short-relative+-1": "viime pe",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-thu-relative+-1": "viime torstaina",
	"field-week": "viikko",
	"quarters-format-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "tänä ke",
	"field-wed-narrow-relative+1": "ensi ke",
	"field-quarter-narrow-relative+-1": "viime nelj.",
	"field-year-short-relative+0": "tänä v",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-year-short-relative+1": "ensi v",
	"field-fri-short-relative+0": "tänä pe",
	"field-fri-short-relative+1": "ensi pe",
	"days-standAlone-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"field-week-short-relative+-1": "viime vk",
	"months-standAlone-abbr-leap": "adár II",
	"field-hour-narrow-relative+0": "tunnin sisällä",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t",
	"quarters-format-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"field-month-narrow": "kk",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "viime pe",
	"field-year-relative+0": "tänä vuonna",
	"field-year-relative+1": "ensi vuonna",
	"field-fri-relative+-1": "viime perjantaina",
	"field-tue-short-relative+-1": "viime ti",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"sunnuntaina",
		"maanantaina",
		"tiistaina",
		"keskiviikkona",
		"torstaina",
		"perjantaina",
		"lauantaina"
	],
	"field-mon-narrow-relative+0": "tänä ma",
	"field-mon-narrow-relative+1": "ensi ma",
	"field-year-short-relative+-1": "viime v",
	"field-zone": "aikavyöhyke",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"months-standAlone-wide-leap": "adárkuu II",
	"field-quarter-narrow": "nelj.",
	"field-sun-short-relative+-1": "viime su",
	"field-day-relative+-1": "eilen",
	"dayPeriods-standAlone-abbr-am": "ap.",
	"field-day-relative+-2": "toissa päivänä",
	"days-format-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"field-sun-relative+0": "tänä sunnuntaina",
	"field-sun-relative+1": "ensi sunnuntaina",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "pv",
	"field-week-narrow": "vk",
	"field-era": "aikakausi",
	"field-fri-narrow-relative+0": "tänä pe",
	"field-fri-narrow-relative+1": "ensi pe",
	"dayPeriods-standAlone-wide-am": "ap."
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/fi/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "tänä neljänneksenä",
	"field-quarter-short-relative+1": "ensi neljänneksenä",
	"field-tue-relative+-1": "viime tiistaina",
	"field-year": "vuosi",
	"dateFormatItem-Hm": "H.mm",
	"field-wed-relative+0": "tänä keskiviikkona",
	"field-wed-relative+1": "ensi keskiviikkona",
	"dateFormatItem-ms": "mm.ss",
	"timeFormat-short": "H.mm",
	"field-minute": "minuutti",
	"field-month-narrow-relative+-1": "viime kk",
	"field-tue-narrow-relative+0": "tänä ti",
	"field-tue-narrow-relative+1": "ensi ti",
	"field-thu-short-relative+0": "tänä to",
	"field-day-short-relative+-1": "eilen",
	"field-thu-short-relative+1": "ensi to",
	"field-day-relative+0": "tänään",
	"field-day-short-relative+-2": "toissap.",
	"field-day-relative+1": "huomenna",
	"field-week-narrow-relative+0": "tällä vk",
	"field-day-relative+2": "ylihuomenna",
	"field-week-narrow-relative+1": "ensi vk",
	"field-wed-narrow-relative+-1": "viime ke",
	"dateFormatItem-EBhms": "E h.mm.ss B",
	"field-year-narrow": "v",
	"field-era-short": "aikakausi",
	"field-year-narrow-relative+0": "tänä v",
	"field-tue-relative+0": "tänä tiistaina",
	"field-year-narrow-relative+1": "ensi v",
	"field-tue-relative+1": "ensi tiistaina",
	"field-weekdayOfMonth": "kuukauden viikonpäivä",
	"field-second-short": "s",
	"dayPeriods-format-narrow-am": "ap.",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "kuukauden vk päivä",
	"dayPeriods-format-abbr-am": "ap.",
	"field-week-relative+0": "tällä viikolla",
	"field-month-relative+0": "tässä kuussa",
	"field-week-relative+1": "ensi viikolla",
	"field-month-relative+1": "ensi kuussa",
	"field-sun-narrow-relative+0": "tänä su",
	"timeFormat-medium": "H.mm.ss",
	"field-mon-short-relative+0": "tänä ma",
	"field-sun-narrow-relative+1": "ensi su",
	"field-mon-short-relative+1": "ensi ma",
	"field-second-relative+0": "nyt",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"T",
		"H",
		"K",
		"T",
		"S",
		"A",
		"A",
		"N",
		"I",
		"S",
		"T",
		"A",
		"E"
	],
	"eraNames": [
		"Anno Mundi"
	],
	"field-weekOfMonth": "kuukauden viikko",
	"dayPeriods-standAlone-abbr-pm": "ip.",
	"field-month-short": "kk",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-day": "päivä",
	"field-dayOfYear-short": "vuodenpv",
	"field-year-relative+-1": "viime vuonna",
	"dayPeriods-format-wide-am": "ap.",
	"field-sat-short-relative+-1": "viime la",
	"field-hour-relative+0": "tämän tunnin aikana",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-second-short-relative+0": "nyt",
	"field-wed-relative+-1": "viime keskiviikkona",
	"dateTimeFormat-medium": "{1} 'klo' {0}",
	"field-sat-narrow-relative+-1": "viime la",
	"field-second": "sekunti",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"dayPeriods-standAlone-wide-pm": "ip.",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "tunnin sisällä",
	"field-quarter": "neljännesvuosi",
	"field-week-short": "vk",
	"field-day-narrow-relative+0": "tänään",
	"field-day-narrow-relative+1": "huom.",
	"field-day-narrow-relative+2": "ylihuom.",
	"quarters-standAlone-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"field-tue-short-relative+0": "tänä ti",
	"field-tue-short-relative+1": "ensi ti",
	"field-month-short-relative+-1": "viime kk",
	"field-mon-relative+-1": "viime maanantaina",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "kuukausi",
	"field-day-narrow": "pv",
	"field-minute-short": "min",
	"field-dayperiod": "vuorokaudenaika",
	"field-sat-short-relative+0": "tänä la",
	"field-sat-short-relative+1": "ensi la",
	"dayPeriods-format-narrow-pm": "ip.",
	"dateFormat-medium": "d.M.y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"quarters-standAlone-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"dayPeriods-format-abbr-pm": "ip.",
	"dateFormatItem-yyyyM": "L.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "tänä maanantaina",
	"field-mon-relative+1": "ensi maanantaina",
	"field-day-narrow-relative+-1": "eilen",
	"field-year-short": "v",
	"field-day-narrow-relative+-2": "toissap.",
	"months-format-narrow": [
		"T",
		"H",
		"K",
		"T",
		"S",
		"A",
		"A",
		"N",
		"I",
		"S",
		"T",
		"A",
		"E"
	],
	"field-quarter-relative+-1": "viime neljännesvuonna",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "vuorokaudenaika",
	"dayPeriods-standAlone-narrow-am": "ap.",
	"field-week-narrow-relative+-1": "viime vk",
	"days-format-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dayPeriods-format-wide-pm": "ip.",
	"field-dayOfYear": "vuodenpäivä",
	"field-sat-relative+-1": "viime lauantaina",
	"dateTimeFormat-long": "{1} 'klo' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-minute-narrow-relative+0": "minuutin sisällä",
	"field-hour": "tunti",
	"months-format-wide": [
		"tišríkuuta",
		"hešvánkuuta",
		"kislévkuuta",
		"tevétkuuta",
		"ševátkuuta",
		"adárkuuta I",
		"adárkuuta",
		"nisánkuuta",
		"ijjárkuuta",
		"sivánkuuta",
		"tammúzkuuta",
		"abkuuta",
		"elúlkuuta"
	],
	"dateFormat-full": "cccc d. MMMM y G",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-Hms": "H.mm.ss",
	"field-quarter-short": "neljännes",
	"field-sat-narrow-relative+0": "tänä la",
	"field-fri-relative+0": "tänä perjantaina",
	"field-sat-narrow-relative+1": "ensi la",
	"field-fri-relative+1": "ensi perjantaina",
	"dateFormatItem-EBhm": "E h.mm B",
	"field-month-narrow-relative+0": "tässä kk",
	"field-month-narrow-relative+1": "ensi kk",
	"field-sun-short-relative+0": "tänä su",
	"field-sun-short-relative+1": "ensi su",
	"field-week-relative+-1": "viime viikolla",
	"field-quarter-short-relative+-1": "viime neljänneksenä",
	"field-minute-short-relative+0": "minuutin sisällä",
	"dateFormatItem-Ehm": "E h.mm a",
	"months-format-abbr": [
		"tišrí",
		"hešván",
		"kislév",
		"tevét",
		"ševát",
		"adár I",
		"adár",
		"nisán",
		"ijjár",
		"siván",
		"tammúz",
		"ab",
		"elúl"
	],
	"field-quarter-relative+0": "tänä neljännesvuonna",
	"field-minute-relative+0": "tämän minuutin aikana",
	"timeFormat-long": "H.mm.ss z",
	"field-quarter-relative+1": "ensi neljännesvuonna",
	"field-wed-short-relative+-1": "viime ke",
	"dateFormat-short": "d.M.y GGGGG",
	"field-thu-short-relative+-1": "viime to",
	"field-year-narrow-relative+-1": "viime v",
	"days-standAlone-wide": [
		"sunnuntai",
		"maanantai",
		"tiistai",
		"keskiviikko",
		"torstai",
		"perjantai",
		"lauantai"
	],
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "viime ma",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "viime to",
	"field-tue-narrow-relative+-1": "viime ti",
	"field-weekOfMonth-short": "kuukauden vk",
	"dateFormatItem-H": "H",
	"dayPeriods-standAlone-narrow-pm": "ip.",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "tänä ke",
	"months-standAlone-wide": [
		"tišríkuu",
		"hešvánkuu",
		"kislévkuu",
		"tevétkuu",
		"ševátkuu",
		"adárkuu I",
		"adárkuu",
		"nisánkuu",
		"ijjárkuu",
		"sivánkuu",
		"tammúzkuu",
		"abkuu",
		"elúlkuu"
	],
	"field-wed-short-relative+1": "ensi ke",
	"field-sun-relative+-1": "viime sunnuntaina",
	"days-standAlone-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"field-second-narrow-relative+0": "nyt",
	"dateTimeFormat-full": "{1} 'klo' {0}",
	"dateFormatItem-hm": "h.mm a",
	"months-format-abbr-leap": "adár II",
	"field-weekday": "viikonpäivä",
	"months-standAlone-narrow-leap": "A",
	"field-day-short-relative+0": "tänään",
	"field-quarter-narrow-relative+0": "tänä nelj.",
	"field-day-short-relative+1": "huom.",
	"field-sat-relative+0": "tänä lauantaina",
	"field-quarter-narrow-relative+1": "ensi nelj.",
	"field-day-short-relative+2": "ylihuom.",
	"field-sat-relative+1": "ensi lauantaina",
	"field-week-short-relative+0": "tällä vk",
	"field-week-short-relative+1": "ensi vk",
	"months-standAlone-abbr": [
		"tišrí",
		"hešván",
		"kislév",
		"tevét",
		"ševát",
		"adár I",
		"adár",
		"nisán",
		"ijjár",
		"siván",
		"tammúz",
		"ab",
		"elúl"
	],
	"months-format-wide-leap": "adárkuuta II",
	"field-dayOfYear-narrow": "vuodenpv",
	"field-month-short-relative+0": "tässä kk",
	"field-month-short-relative+1": "ensi kk",
	"field-weekdayOfMonth-short": "kuukauden vk päivä",
	"timeFormat-full": "H.mm.ss zzzz",
	"dateFormatItem-MEd": "E d.M.",
	"field-zone-narrow": "aikavyöhyke",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "tänä to",
	"field-thu-narrow-relative+1": "ensi to",
	"field-sun-narrow-relative+-1": "viime su",
	"field-mon-short-relative+-1": "viime ma",
	"field-thu-relative+0": "tänä torstaina",
	"field-thu-relative+1": "ensi torstaina",
	"field-fri-short-relative+-1": "viime pe",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-thu-relative+-1": "viime torstaina",
	"field-week": "viikko",
	"quarters-format-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "tänä ke",
	"field-wed-narrow-relative+1": "ensi ke",
	"field-quarter-narrow-relative+-1": "viime nelj.",
	"field-year-short-relative+0": "tänä v",
	"field-dayperiod-short": "vuorokaudenaika",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-year-short-relative+1": "ensi v",
	"field-fri-short-relative+0": "tänä pe",
	"field-fri-short-relative+1": "ensi pe",
	"days-standAlone-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"field-week-short-relative+-1": "viime vk",
	"months-standAlone-abbr-leap": "adár II",
	"field-hour-narrow-relative+0": "tunnin sisällä",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t",
	"field-zone-short": "aikavyöhyke",
	"quarters-format-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"field-month-narrow": "kk",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "viime pe",
	"field-year-relative+0": "tänä vuonna",
	"field-year-relative+1": "ensi vuonna",
	"field-era-narrow": "aikakausi",
	"field-fri-relative+-1": "viime perjantaina",
	"dateFormatItem-Bhms": "h.mm.ss B",
	"field-tue-short-relative+-1": "viime ti",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"sunnuntaina",
		"maanantaina",
		"tiistaina",
		"keskiviikkona",
		"torstaina",
		"perjantaina",
		"lauantaina"
	],
	"field-mon-narrow-relative+0": "tänä ma",
	"field-mon-narrow-relative+1": "ensi ma",
	"dateFormatItem-EHm": "E HH.mm",
	"field-year-short-relative+-1": "viime v",
	"field-zone": "aikavyöhyke",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"field-weekOfMonth-narrow": "kuukauden vk",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"field-weekday-narrow": "viikonpäivä",
	"months-standAlone-wide-leap": "adárkuu II",
	"field-quarter-narrow": "nelj.",
	"field-sun-short-relative+-1": "viime su",
	"field-day-relative+-1": "eilen",
	"dayPeriods-standAlone-abbr-am": "ap.",
	"field-day-relative+-2": "toissa päivänä",
	"field-weekday-short": "viikonpäivä",
	"days-format-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dateFormatItem-Bhm": "h.mm B",
	"field-sun-relative+0": "tänä sunnuntaina",
	"field-sun-relative+1": "ensi sunnuntaina",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "pv",
	"field-week-narrow": "vk",
	"field-era": "aikakausi",
	"field-fri-narrow-relative+0": "tänä pe",
	"field-fri-narrow-relative+1": "ensi pe",
	"dayPeriods-standAlone-wide-am": "ap."
}
//end v1.x content
);
